]> git.sesse.net Git - cubemap/blobdiff - client.h
Add suppor for raw (non-Metacube) inputs over HTTP. Only really useful for TS.
[cubemap] / client.h
index c73810df5e726297e8258c3997df3498fe32e7c7..2ee478375fd9edcda5da464c90907b0e41f7e0e6 100644 (file)
--- a/client.h
+++ b/client.h
@@ -11,12 +11,14 @@ class ClientProto;
 struct Stream;
 
 // Digested statistics for writing to logs etc.
+// Note that "referer" and "user_agent" here are already escaped for scary characters.
 struct ClientStats {
        std::string url;
        int sock;
-       int fwmark;
        std::string remote_addr;
-       time_t connect_time;
+       std::string referer;
+       std::string user_agent;
+       timespec connect_time;
        size_t bytes_sent;
        size_t bytes_lost;
        size_t num_loss_events;
@@ -34,14 +36,15 @@ struct Client {
        // The file descriptor associated with this socket.
        int sock;
 
-       // The fwmark associated with this socket (or 0).
-       int fwmark;
+       // When the client connected, in terms of CLOCK_MONOTONIC_COARSE.
+       timespec connect_time;
 
        // Some information only used for logging.
        std::string remote_addr;
-       time_t connect_time;
+       std::string referer;
+       std::string user_agent;
 
-       enum State { READING_REQUEST, SENDING_HEADER, SENDING_DATA, SENDING_ERROR };
+       enum State { READING_REQUEST, SENDING_HEADER, SENDING_DATA, SENDING_SHORT_RESPONSE, WAITING_FOR_KEYFRAME, PREBUFFERING };
        State state;
 
        // The HTTP request, as sent by the client. If we are in READING_REQUEST,
@@ -53,17 +56,23 @@ struct Client {
        std::string url;
        Stream *stream;
 
-       // The header we want to send. This is nominally a copy of Stream::header,
-       // but since that might change on reconnects etc., we keep a local copy here.
-       // Only relevant for SENDING_HEADER or SENDING_ERROR; blank otherwise.
-       std::string header_or_error;
+       // The header we want to send, or the response with headers if we know
+       // it in its entirety after reading the request (typically an error).
+       // This is nominally a copy of Stream::header, but since that might
+       // change on reconnects etc., we keep a local copy here. Only relevant
+       // for SENDING_HEADER or SENDING_SHORT_RESPONSE; blank otherwise.
+       std::string header_or_short_response;
 
        // Number of bytes we've sent of the header. Only relevant for SENDING_HEADER
-       // or SENDING_ERROR.
-       size_t header_or_error_bytes_sent;
+       // or SENDING_SHORT_RESPONSE.
+       size_t header_or_short_response_bytes_sent;
 
        // Number of bytes we are into the stream (ie., the end of last send).
-       // Only relevant for SENDING_DATA.
+       // -1 means we want to send from the end of the backlog (the normal case),
+       // although only at a keyframe.
+       // -2 means we want to send from the _beginning_ of the backlog.
+       // Once we go into WAITING_FOR_KEYFRAME, PREBUFFERING or SENDING_DATA,
+       // these negative values will be translated to real numbers.
        size_t stream_pos;
 
        // Number of bytes we've sent of data. Only relevant for SENDING_DATA.